=== modified file 'hooks/keystone-hooks'
--- hooks/keystone-hooks	2012-12-18 13:46:21 +0000
+++ hooks/keystone-hooks	2013-01-07 12:37:48 +0000
@@ -8,7 +8,7 @@
 
 config = config_get()
 
-packages = "keystone python-mysqldb pwgen haproxy"
+packages = "keystone python-mysqldb pwgen haproxy python-jinja2"
 service = "keystone"
 
 # used to verify joined services are valid openstack components.

=== modified file 'hooks/lib/openstack_common.py'
--- hooks/lib/openstack_common.py	2012-12-17 17:02:04 +0000
+++ hooks/lib/openstack_common.py	2013-01-07 12:37:48 +0000
@@ -3,6 +3,7 @@
 # Common python helper functions used for OpenStack charms.
 
 import subprocess
+import os
 
 CLOUD_ARCHIVE_URL = "http://ubuntu-cloud.archive.canonical.com/ubuntu"
 CLOUD_ARCHIVE_KEY_ID = '5EDB1B62EC4926EA'
@@ -194,52 +195,22 @@
 
 HAPROXY_CONF = '/etc/haproxy/haproxy.cfg'
 HAPROXY_DEFAULT = '/etc/default/haproxy'
-HAPROXY_CONTENT = """global
-    log 127.0.0.1 local0
-    log 127.0.0.1 local1 notice
-    maxconn 4096
-    user haproxy
-    group haproxy
-    spread-checks 0
-
-defaults
-    log global
-    mode http
-    option httplog
-    option dontlognull
-    retries 3
-    timeout queue 1000
-    timeout connect 1000
-    timeout client 1000
-    timeout server 1000
-
-listen stats :8888
-    mode http
-    stats enable
-    stats hide-version
-    stats realm Haproxy\ Statistics
-    stats uri /
-    stats auth admin:password
-"""
-SERVICE_FRAGMENT = """listen {0} 0.0.0.0:{1}
-    balance  roundrobin
-    option  tcplog
-"""
-SERVER_ENTRY = """    server {0} {1}:{2} check
-"""
-
-
-def configure_haproxy(units, service_ports):
-    conf = HAPROXY_CONTENT
-    for service, port in service_ports.iteritems():
-        conf = conf + SERVICE_FRAGMENT.format(service,
-                                              port)
-        for unit, address in units.iteritems():
-            conf = conf + SERVER_ENTRY.format(unit,
-                                              address,
-                                              port-1)
+
+
+def configure_haproxy(units, service_ports, template_dir=None):
+    template_dir = template_dir or 'templates'
+    import jinja2
+    context = {
+        'units': units,
+        'service_ports': service_ports
+        }
+    templates = jinja2.Environment(
+                    loader=jinja2.FileSystemLoader(template_dir)
+                    )
+    template = templates.get_template(
+                    os.path.basename(HAPROXY_CONF)
+                    )
     with open(HAPROXY_CONF, 'w') as f:
-        f.write(conf)
+        f.write(template.render(context))
     with open(HAPROXY_DEFAULT, 'w') as f:
         f.write('ENABLED=1')
-

=== modified file 'revision'
--- revision	2012-12-18 13:46:21 +0000
+++ revision	2013-01-07 12:37:48 +0000
@@ -1,1 +1,1 @@
-186
+190

=== added directory 'templates'
=== added file 'templates/haproxy.cfg'
--- templates/haproxy.cfg	1970-01-01 00:00:00 +0000
+++ templates/haproxy.cfg	2013-01-07 12:37:48 +0000
@@ -0,0 +1,35 @@
+global
+    log 127.0.0.1 local0
+    log 127.0.0.1 local1 notice
+    maxconn 4096
+    user haproxy
+    group haproxy
+    spread-checks 0
+
+defaults
+    log global
+    mode http
+    option httplog
+    option dontlognull
+    retries 3
+    timeout queue 1000
+    timeout connect 1000
+    timeout client 1000
+    timeout server 1000
+
+listen stats :8888
+    mode http
+    stats enable
+    stats hide-version
+    stats realm Haproxy\ Statistics
+    stats uri /
+    stats auth admin:password
+
+{% for service, port in service_ports.iteritems() -%}
+listen {{ service }} 0.0.0.0:{{ port }}
+    balance roundrobin
+    option tcplog
+    {% for unit, address in units.iteritems() -%}
+    server {{ unit }} {{ address }}:{{ port - 1 }} check
+    {% endfor %}
+{% endfor %}

